@@ -11,17 +11,21 @@ use syn::{
     Attribute, DeriveInput, Error as SynError, Expr, Generics, Ident, Type, Visibility,
 };
 
+use crate::attributes::{RenameAllAttribute, RenameAttribute};
+
 pub struct Input {
     pub ident: Ident,
-    pub rename_all: Option<String>,
+    pub rename_all: Option<RenameAllAttribute>,
     pub variants: Vec<Variant>,
     pub default_variant: Option<DefaultVariant>,
 }
 
 pub struct Variant {
     pub ident: Ident,
-    pub rename: Option<String>,
+    pub rename: Option<RenameAttribute>,
     pub alias_vec: Option<Vec<String>>,
+    pub skip_serializing: Option<bool>,
+    pub skip_deserializing: Option<bool>,
 }
 
 #[derive(Clone)]
@@ -60,10 +64,7 @@ impl Parse for Input {
                     SynError::new(enum_variant.ident.span(), "must be at least one type")
                 })?;
                 if types_iter.next().is_some() {
-                    return Err(SynError::new(
-                        enum_variant.ident.span(),
-                        "must be at least one type",
-                    ));
+                    return Err(SynError::new(enum_variant.ident.span(), "must be one type"));
                 }
 
                 default_variants.push(DefaultVariant {
@@ -86,6 +87,8 @@ impl Parse for Input {
                     } else {
                         Some(enum_variant.alias_vec.to_owned())
                     },
+                    skip_serializing: enum_variant.skip_serializing.or(enum_variant.skip),
+                    skip_deserializing: enum_variant.skip_deserializing.or(enum_variant.skip),
                 });
             }
         }
@@ -127,7 +130,7 @@ struct EnumDeriveInput {
     data: Data<EnumVariant, Ignored>,
 
     #[darling(default)]
-    rename_all: Option<String>,
+    rename_all: Option<RenameAllAttribute>,
 }
 
 #[derive(FromVariant, Debug)]
@@ -139,9 +142,15 @@ struct EnumVariant {
     discriminant: Option<Expr>,
 
     #[darling(default)]
-    rename: Option<String>,
+    rename: Option<RenameAttribute>,
     #[darling(default, multiple, rename = "alias")]
     alias_vec: Vec<String>,
+    #[darling(default)]
+    skip: Option<bool>,
+    #[darling(default)]
+    skip_serializing: Option<bool>,
+    #[darling(default)]
+    skip_deserializing: Option<bool>,
     #[darling(default, rename = "other", map = "Self::make_is_other")]
     is_other: bool,
 }
